@@ -45,7 +45,7 @@ StateNames = Literal["light", "motion", "audio", "doorbell", "siren", "battery",
 CameraPublicProperties = Literal[
     "_id",
     "nativeId",
-    "pluginId",
+    "pluginInfo",
     "name",
     "disabled",
     "isCloud",
@@ -572,10 +572,15 @@ class CameraExtensions(TypedDict):
     plugins: list[Extension]
 
 
+class CameraPluginInfo(TypedDict):
+    id: str
+    name: str
+
+
 class Camera(TypedDict):
     _id: str
     nativeId: Optional[str]
-    pluginId: str
+    pluginInfo: Optional[CameraPluginInfo]
     name: str
     disabled: bool
     isCloud: bool
@@ -715,7 +720,7 @@ class CameraDevice(Protocol):
     @property
     def native_id(self) -> Optional[str]: ...
     @property
-    def plugin_id(self) -> str: ...
+    def plugin_info(self) -> Optional[CameraPluginInfo]: ...
     @property
     def connected(self) -> bool: ...
     @property
